@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "binky" "2.2.0"
+(define-package "binky" "20250123.1928"
   "Jump between points like a rabbit."
   '((emacs "29.1")
     (dash  "2.19.1"))
